#
# spec file for package libupnp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011, Sascha Peilicke <saschpe@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libupnp6

Name:           libupnp
Version:        1.6.21
Release:        5.1
Summary:        Portable Universal Plug and Play (UPnP) SDK
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://sourceforge.net/projects/pupnp/
Source0:        http://downloads.sourceforge.net/pupnp/libupnp-%{version}.tar.bz2
Source1:        http://sourceforge.net/projects/pupnp/files/pupnp/libUPnP%20%version/libupnp-%version.tar.bz2.sha1
Source42:       baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libtool
BuildRequires:  pkgconfig
Patch:          libupnp-configure.patch

%description
The portable Universal Plug and Play (UPnP) SDK provides support for building
UPnP-compliant control points, devices, and bridges on several operating
systems.

%package -n %lname 
Summary:        Portable Universal Plug and Play (UPnP) SDK
# Replace individual packages from Packman to make migration to Tumbleweed easier.
Group:          System/Libraries
Provides:       libixml2 = %{version}-%{release}
Obsoletes:      libixml2 < %{version}
Provides:       libthreadutil6 = %{version}-%{release}
Obsoletes:      libthreadutil6 < %{version}

%description -n %lname
The portable Universal Plug and Play (UPnP) SDK provides support for building
UPnP-compliant control points, devices, and bridges on several operating
systems

%package -n libupnp-devel
Summary:        Portable Universal Plug and Play (UPnP) SDK
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description -n libupnp-devel
The portable Universal Plug and Play (UPnP) SDK provides support for building
UPnP-compliant control points, devices, and bridges on several operating
systems.

%prep
%setup -q
%patch -p1

%build
autoreconf -fiv
%configure --disable-samples --enable-ipv6 --disable-static
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -type f -name '*.la' -delete

%post -p /sbin/ldconfig -n %lname

%postun -p /sbin/ldconfig -n %lname

%files -n %lname
%defattr(-,root,root,-)
%doc ChangeLog NEWS README TODO LICENSE
%{_libdir}/libixml.so.*
%{_libdir}/libthreadutil.so.*
%{_libdir}/libupnp.so.*

%files -n libupnp-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libupnp.pc
%{_libdir}/libixml.so
%{_libdir}/libthreadutil.so
%{_libdir}/libupnp.so
%{_includedir}/upnp/

%changelog
* Thu Mar  2 2017 jengelh@inai.de
- Rectify RPM groups, use find -delete over -exec rm.
* Fri Feb 24 2017 olaf@aepfle.de
- Update to version 1.6.21 (bsc#898167)
  * use stderr if log file cannot be opened
  * fix out-of-bounds access [CVE-2016-8863] (bsc#1006256)
  * miniserver: fix binding to ipv6 link-local addresses
  * fix for file write via POST [CVE-2016-6255] (bsc#989948)
- Replace individual packages from Packman to make migration to
  Tumbleweed easier.
- Package LICENSE file
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 1.6.19
  * Fix access violation due to changed usage of pthreads-win32
    (closes SF Bug Tracker #119)
- Update libupnp-configure.patch
- added baselibs.conf to sources
- add .sha1 download from sf ... (not much useful)
* Tue Feb  5 2013 zaitor@opensuse.org
- Update to version 1.6.18:
  + Security fix for CERT issue VU#922681.
  + CVE-2012-5958 Issue #2: Stack buffer overflow of Tempbuf
  + CVE-2012-5959 Issue #4: Stack buffer overflow of Event->UDN
  + CVE-2012-5960 Issue #8: Stack buffer overflow of Event->UDN
  + Notice that the following issues have already been dealt by
    previous work:
  - CVE-2012-5961 Issue #1: Stack buffer overflow of Evt->UDN
  - CVE-2012-5962 Issue #3: Stack buffer overflow of
    Evt->DeviceType
  - CVE-2012-5963 Issue #5: Stack buffer overflow of Event->UDN
  - CVE-2012-5964 Issue #6: Stack buffer overflow of
    Event->DeviceType
  - CVE-2012-5965 Issue #7: Stack buffer overflow of
    Event->DeviceType
  + Fix memory leak and access violation in
    UpnpSendAction(Ex)Async.
  + Disable SetGenaCallback call if device is disabled.
  + Fix problems detected as dead assignment warning by clang
    scan-build.
  + Fix condition for allocation failure in get_content_type().
  + Avoid dereference of null pointer in
    ixmlNode_setNodeProperties.
  + Avoid access violation after parser_parse_chunky_headers call.
  + Remove possibility of access violation.
  + Fix type of local variable stopSock in RunMiniServer().
  + Compilation optimisation.
  + Use of thread-unsafe gmtime() in httpreadwrite.c sf#3507819.
- Changes from version 1.6.17:
  + Remove implicit casts.
  + Add --enable-unspecified_server
  + Removing implicit casts in miniserver.c
  + Bugs fixed: sf#3512833, sf#3510693, sf#3511149, sf#3514145.
- Changes from version 1.6.16:
  + Replace sprintf by snprintf in http_WriteHttpPost to avoid
    buffer overflow.
  + Add infoSize parameter to get_sdk_info
  + Check return code in ixml.
  + Add --disable-optssdp option
  + Add more explicit casts and remove dead code.
  + Bug fix in ixmlNode_allowChildren.
  + Improve upnp/genlib/net.
  + Improve ssdp part. Do not compile
    CreateClientRequestPacketUlaGua if IPv6 is disabled.
  + Bugs fixed: sf#3502958, sf#3499781, sf#3499878, sf#3175217,
    sf#3496993, sf#3497714, sf#3498442, sf#3498439, sf#3498436,
    sf#3497714, sf#2989399, sf#3325246, sf#3417134, sf#3497159,
    sf#3497140, sf#3497126, sf#3497034, sf#3497033, sf#3497027,
    sf#3497009, sf#3496703, sf#3496702, sf#3496942, sf#3496938,
    sf#3496934, sf#3496933, sf#3496581, sf#3495616, sf#3495286,
    sf#3495280, sf#3494865, sf#3489999, sf#3489990, sf#3489999.
- Changes from version 1.6.15:
  + Bug fix on M-SEARCH for IPv6 CPs.
  + Retrieve IPv6 addresses in Upnp_Discovery.
  + Fix bug sf#3469344.
- Changes from version 1.6.14:
  + UPnP Low Power Support.
  + Bug fix in IN6_IS_ADDR_GLOBAL.
  + Bug Fix on M-SEARCH.
  + Fixes for compilation under Windows.
  + Several fixes to correctly use SOCKET (and related) types
    instead of non-portable variations.
- Rebase libupnp-configure.patch.
* Sun Feb  3 2013 crrodriguez@opensuse.org
- Previous patch was incomplete and did not consider files
  in the upnp directory. (updates libupnp-configure.patch)
* Tue Jul 17 2012 crrodriguez@opensuse.org
- Enable IPV6 support...
- Fix autotools, all C files must include "*config.h"
- DO not build samples
* Sat Feb 25 2012 coolo@suse.com
- sync package name with spec file name
* Mon Jan 30 2012 jengelh@medozas.de
- Properly provide pkgconfig symbols
* Sat Oct  8 2011 saschpe@gmx.de
- Initial version
